@@ -81,6 +81,15 @@ var CommonFlags = flag.Set{
 		Description: "Create spare machines that increases app availability",
 		Default:     true,
 	},
+	flag.Bool{
+		Name:        "smoke-checks",
+		Description: "Perform smoke checks during deployment",
+		Default:     true,
+	},
+	flag.Bool{
+		Name:        "no-public-ips",
+		Description: "Do not allocate any new public IP addresses",
+	},
 }
 
 func New() (cmd *cobra.Command) {
@@ -170,6 +179,10 @@ func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, args Dep
 			return err
 		}
 	default:
+		if flag.GetBool(ctx, "no-public-ips") {
+			return fmt.Errorf("The --no-public-ips flag can only be used for v2 apps")
+		}
+
 		err = deployToNomad(ctx, appConfig, appCompact, img)
 		if err != nil {
 			return err
@@ -198,11 +211,13 @@ func deployToMachines(ctx context.Context, appConfig *appconfig.Config, appCompa
 		Strategy:              flag.GetString(ctx, "strategy"),
 		EnvFromFlags:          flag.GetStringSlice(ctx, "env"),
 		PrimaryRegionFlag:     appConfig.PrimaryRegion,
+		SkipSmokeChecks:       flag.GetDetach(ctx) || !flag.GetBool(ctx, "smoke-checks"),
 		SkipHealthChecks:      flag.GetDetach(ctx),
 		WaitTimeout:           time.Duration(flag.GetInt(ctx, "wait-timeout")) * time.Second,
 		LeaseTimeout:          time.Duration(flag.GetInt(ctx, "lease-timeout")) * time.Second,
 		VMSize:                flag.GetString(ctx, "vm-size"),
 		IncreasedAvailability: flag.GetBool(ctx, "ha"),
+		AllocPublicIP:         !flag.GetBool(ctx, "no-public-ips"),
 	})
 	if err != nil {
 		sentry.CaptureExceptionWithAppInfo(err, "deploy", appCompact)
