@@ -36,12 +36,14 @@ type MachineDeploymentArgs struct {
 	Strategy              string
 	EnvFromFlags          []string
 	PrimaryRegionFlag     string
+	SkipSmokeChecks       bool
 	SkipHealthChecks      bool
 	RestartOnly           bool
 	WaitTimeout           time.Duration
 	LeaseTimeout          time.Duration
 	VMSize                string
 	IncreasedAvailability bool
+	AllocPublicIP         bool
 }
 
 type machineDeployment struct {
@@ -59,6 +61,7 @@ type machineDeployment struct {
 	strategy              string
 	releaseId             string
 	releaseVersion        int
+	skipSmokeChecks       bool
 	skipHealthChecks      bool
 	restartOnly           bool
 	waitTimeout           time.Duration
@@ -120,6 +123,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 		app:                   args.AppCompact,
 		appConfig:             appConfig,
 		img:                   args.DeploymentImage,
+		skipSmokeChecks:       args.SkipSmokeChecks,
 		skipHealthChecks:      args.SkipHealthChecks,
 		restartOnly:           args.RestartOnly,
 		waitTimeout:           waitTimeout,
@@ -147,7 +151,7 @@ func NewMachineDeployment(ctx context.Context, args MachineDeploymentArgs) (Mach
 	}
 
 	// Provisioning must come after setVolumes
-	if err := md.provisionFirstDeploy(ctx); err != nil {
+	if err := md.provisionFirstDeploy(ctx, args.AllocPublicIP); err != nil {
 		return nil, err
 	}
 
