@@ -3,13 +3,12 @@ package info
 import (
 	"context"
 	"fmt"
-	"strings"
 
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/command/apps"
+	"github.com/superfly/flyctl/internal/command/services"
 	"github.com/superfly/flyctl/internal/flag"
-	"github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -24,6 +23,11 @@ func showMachineInfo(ctx context.Context, appName string) error {
 		return fmt.Errorf("outputting to json is not yet supported")
 	}
 
+	appInfo, err := client.GetAppInfo(ctx, appName)
+	if err != nil {
+		return err
+	}
+
 	app, err := client.GetAppCompact(ctx, appName)
 	if err != nil {
 		return err
@@ -38,7 +42,7 @@ func showMachineInfo(ctx context.Context, appName string) error {
 		return err
 	}
 
-	if err := showMachineServiceInfo(ctx, app); err != nil {
+	if err := services.ShowMachineServiceInfo(ctx, appInfo); err != nil {
 		return err
 	}
 
@@ -70,49 +74,6 @@ func showMachineAppInfo(ctx context.Context, app *api.AppCompact) error {
 	return nil
 }
 
-func showMachineServiceInfo(ctx context.Context, app *api.AppCompact) error {
-	var (
-		io = iostreams.FromContext(ctx)
-	)
-
-	machines, err := machine.ListActive(ctx)
-	if err != nil {
-		return err
-	}
-
-	if len(machines) == 0 {
-		fmt.Fprintf(io.ErrOut, "No machines found")
-		return nil
-	}
-
-	services := [][]string{}
-	for _, service := range machines[0].Config.Services {
-		for i, port := range service.Ports {
-			protocol := service.Protocol
-			if i > 0 {
-				protocol = ""
-			}
-
-			handlers := []string{}
-			for _, handler := range port.Handlers {
-				handlers = append(handlers, strings.ToUpper(handler))
-			}
-
-			fields := []string{
-				strings.ToUpper(protocol),
-				fmt.Sprintf("%d => %d [%s]", port.Port, service.InternalPort, strings.Join(handlers, ",")),
-				strings.Title(fmt.Sprint(port.ForceHttps)),
-			}
-			services = append(services, fields)
-		}
-
-	}
-
-	_ = render.Table(io.Out, "Services", services, "Protocol", "Ports", "Force HTTPS")
-
-	return nil
-}
-
 func showMachineIPInfo(ctx context.Context, appName string) error {
 	var (
 		io     = iostreams.FromContext(ctx)
