@@ -16,6 +16,7 @@ import (
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/deploy"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/metrics"
 	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/iostreams"
 	"github.com/superfly/flyctl/scanner"
@@ -89,6 +90,11 @@ func run(ctx context.Context) (err error) {
 		ForceYes:      flag.GetBool(ctx, "now"),
 	}
 
+	metrics.Started(ctx, "launch")
+	defer func() {
+		metrics.Status(ctx, "launch", err == nil)
+	}()
+
 	// Determine the working directory
 	if absDir, err := filepath.Abs(workingDir); err == nil {
 		workingDir = absDir
